Documentation
¶
Index ¶
Constants ¶
const ( // BrokerQueue is the name we use to queueSub to a queue with the broker BrokerQueue = "broker_queue" // DefaultPoolSize is the default size of the worker pool DefaultPoolSize = 5 // DefaultPoolMaxPending is the default number of requests that can be // pending DefaultPoolMaxPending = 5 // DefaultPoolMaxPendingDuration is the default max pending duration for a // a request DefaultPoolMaxPendingDuration = time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
services.Options
ActorStorage storage.ActorStorage
EnvelopeStorage storage.EnvelopeStorage
LogStorage storage.LogStorage
ProcessManager *process.Manager
PoolSize uint
PoolMaxPending uint
PoolMaxPendingDuration time.Duration
}
Options is used to create a Service
type Service ¶
type Service struct {
services.BaseService
Opts Options
// contains filtered or unexported fields
}
Service is the central node of all envelope exchanges
Click to show internal directories.
Click to hide internal directories.