Documentation
¶
Index ¶
Constants ¶
const ( // ServiceName name of the service ServiceName = "envelopestorage" // QueueName queue name for queuesubscribes QueueName = "xbus.services." + ServiceName )
Variables ¶
var ( // EnvelopeStallDelay is the delay after which an envelope is marked stalled // when its emitter stops sending fragments. // TODO in a later version, this value should be envelope-dependant and be // set by the emitter itself (within reasonnable limits) EnvelopeStallDelay = 30 * time.Second )
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
services.Options
EnvelopeStorage storage.EnvelopeStorage
JobStorage storage.JobStorage
}
Options is used to create a 'envelopestorage' service
type Service ¶
type Service struct {
services.BaseService
// contains filtered or unexported fields
}
Service is in charge of emitting process status events to various subjects
Click to show internal directories.
Click to hide internal directories.